@@ -21,19 +21,16 @@
 #include "config.h"
 
 #include "ev-document.h"
+
 #include "ev-backend-marshalers.h"
+#include "ev-job-queue.h"
 
 static void ev_document_class_init (gpointer g_class);
 
-enum
-{
-	PAGE_CHANGED,
-	SCALE_CHANGED,
-	LAST_SIGNAL
-};
 
-static guint signals[LAST_SIGNAL] = { 0 };
+GMutex *ev_doc_mutex = NULL;
 
+#define LOG(x) 
 GType
 ev_document_get_type (void)
 {
@@ -70,26 +67,6 @@ ev_document_error_quark (void)
 static void
 ev_document_class_init (gpointer g_class)
 {
-	signals[PAGE_CHANGED] =
-		g_signal_new ("page_changed",
-			      EV_TYPE_DOCUMENT,
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EvDocumentIface, page_changed),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
-
-	signals[SCALE_CHANGED] =
-		g_signal_new ("scale_changed",
-			      EV_TYPE_DOCUMENT,
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (EvDocumentIface, scale_changed),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
-
 	g_object_interface_install_property (g_class,
 				g_param_spec_string ("title",
 						     "Document Title",
@@ -98,13 +75,49 @@ ev_document_class_init (gpointer g_class)
 						     G_PARAM_READABLE));
 }
 
+#define PAGE_CACHE_STRING "ev-page-cache"
+
+EvPageCache *
+ev_document_get_page_cache (EvDocument *document)
+{
+	EvPageCache *page_cache;
+
+	g_return_val_if_fail (EV_IS_DOCUMENT (document), NULL);
+
+	page_cache = g_object_get_data (G_OBJECT (document), PAGE_CACHE_STRING);
+	if (page_cache == NULL) {
+		page_cache = _ev_page_cache_new (document);
+		g_object_set_data_full (G_OBJECT (document), PAGE_CACHE_STRING, page_cache, g_object_unref);
+	}
+
+	return page_cache;
+}
+
+GMutex *
+ev_document_get_doc_mutex (void)
+{
+	if (ev_doc_mutex == NULL) {
+		ev_doc_mutex = g_mutex_new ();
+	}
+	return ev_doc_mutex;
+}
+
+
 gboolean
 ev_document_load (EvDocument  *document,
 		  const char  *uri,
 		  GError     **error)
 {
 	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
-	return iface->load (document, uri, error);
+	gboolean retval;
+	LOG ("ev_document_load");
+	retval = iface->load (document, uri, error);
+
+	/* Call this to make the initial cached copy */
+	if (retval)
+		ev_document_get_page_cache (document);
+
+	return retval;
 }
 
 gboolean
@@ -113,7 +126,12 @@ ev_document_save (EvDocument  *document,
 		  GError     **error)
 {
 	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
-	return iface->save (document, uri, error);
+	gboolean retval;
+
+	LOG ("ev_document_save");
+	retval = iface->save (document, uri, error);
+
+	return retval;
 }
 
 char *
@@ -121,6 +139,7 @@ ev_document_get_title (EvDocument  *document)
 {
 	char *title;
 
+	LOG ("ev_document_get_title");
 	g_object_get (document, "title", &title, NULL);
 
 	return title;
@@ -130,95 +149,83 @@ int
 ev_document_get_n_pages (EvDocument  *document)
 {
 	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
-	return iface->get_n_pages (document);
-}
+	gint retval;
 
-void
-ev_document_set_page (EvDocument  *document,
-		      int          page)
-{
-	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
-	iface->set_page (document, page);
-}
+	LOG ("ev_document_get_n_pages");
+	retval = iface->get_n_pages (document);
 
-int
-ev_document_get_page (EvDocument *document)
-{
-	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
-	return iface->get_page (document);
-}
-
-void
-ev_document_set_target (EvDocument  *document,
-			GdkDrawable *target)
-{
-	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
-	iface->set_target (document, target);
-}
-
-void
-ev_document_set_scale (EvDocument   *document,
-		       double        scale)
-{
-	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
-	iface->set_scale (document, scale);
-}
-
-void
-ev_document_set_page_offset (EvDocument  *document,
-			     int          x,
-			     int          y)
-{
-	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
-	iface->set_page_offset (document, x, y);
+	return retval;
 }
 
 void
 ev_document_get_page_size   (EvDocument   *document,
 			     int           page,
-			     int          *width,
-			     int          *height)
+			     double       *width,
+			     double       *height)
 {
 	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
+
+	LOG ("ev_document_get_page_size");
 	iface->get_page_size (document, page, width, height);
 }
 
 char *
-ev_document_get_text (EvDocument   *document,
-		      GdkRectangle *rect)
+ev_document_get_page_label(EvDocument    *document,
+			   int             page)
 {
 	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
-	return iface->get_text (document, rect);
+
+	LOG ("ev_document_get_page_label");
+	if (iface->get_page_label == NULL)
+		return NULL;
+
+	return iface->get_page_label (document, page);
 }
 
-EvLink *
-ev_document_get_link (EvDocument   *document,
-		      int           x,
-		      int	    y)
+char *
+ev_document_get_text (EvDocument  *document,
+		      int          page,
+		      EvRectangle *rect)
 {
 	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
-	return iface->get_link (document, x, y);
+	char *retval;
+
+	LOG ("ev_document_get_text");
+	retval = iface->get_text (document, page, rect);
+
+	return retval;
 }
 
-void
-ev_document_render (EvDocument  *document,
-		    int          clip_x,
-		    int          clip_y,
-		    int          clip_width,
-		    int          clip_height)
+GList *
+ev_document_get_links (EvDocument *document,
+		       int         page)
 {
 	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
-	iface->render (document, clip_x, clip_y, clip_width, clip_height);
+	GList *retval;
+
+	LOG ("ev_document_get_link");
+	if (iface->get_links == NULL)
+		return NULL;
+	retval = iface->get_links (document, page);
+
+	return retval;
 }
 
-void
-ev_document_page_changed (EvDocument *document)
+
+
+GdkPixbuf *
+ev_document_render_pixbuf (EvDocument *document,
+			   int         page,
+			   double      scale)
 {
-	g_signal_emit (G_OBJECT (document), signals[PAGE_CHANGED], 0);
+	EvDocumentIface *iface = EV_DOCUMENT_GET_IFACE (document);
+	GdkPixbuf *retval;
+
+	LOG ("ev_document_render_pixbuf");
+	g_assert (iface->render_pixbuf);
+
+	retval = iface->render_pixbuf (document, page, scale);
+
+	return retval;
 }
 
-void
-ev_document_scale_changed (EvDocument *document)
-{
-	g_signal_emit (G_OBJECT (document), signals[SCALE_CHANGED], 0);
-}		    
