@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: main.c,v 1.7 2005/02/07 21:11:11 marco Exp $
+ *  $Id: main.c,v 1.9 2005/03/23 11:07:32 marco Exp $
  */
 
 #include "config.h"
@@ -30,6 +30,7 @@
 
 #include "ev-stock-icons.h"
 #include "ev-debug.h"
+#include "ev-job-queue.h"
 
 static struct poptOption popt_options[] =
 {
@@ -82,10 +83,12 @@ main (int argc, char *argv[])
 				      GNOME_PARAM_APP_DATADIR, DATADIR,
                                       NULL);
 
+	ev_job_queue_init ();
 	g_set_application_name (_("Evince Document Viewer"));
 
 	ev_debug_init ();
 	ev_stock_icons_init ();
+	gtk_window_set_default_icon_name ("postscript-viewer");
 
 	g_object_get_property (G_OBJECT (program),
                                GNOME_PARAM_POPT_CONTEXT,
